:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

2.11.3 (not yet released)
-------------------------

2.11.2 (November 1st 2018)
--------------------------

* New: Support Django autocomplete functionality.
* New: Allow HTML with related labels (if marked as safe).
* Improved: Incorporate `Reset to default` functionality from `constance`.
* Fixed: Styles with Firefox.
* Fixed: Multiple selection boxes.
* Fixed: Removed obsolete `field.rel`.
* Fixed: Reversion template localization bug using upstream fix.
* Fixed: Ensure LICENSE is included in the built wheel.
* Fixed: Translate Save button with ChangeList.
* Fixed: Django version with Quickstart.

2.11.1 (January 27th 2018)
--------------------------

* First release of Grappelli which is compatible with Django 2.0.
